Index: src/uk/me/parabola/mkgmap/general/MapLine.java
===================================================================
--- src/uk/me/parabola/mkgmap/general/MapLine.java	(revision 4725)
+++ src/uk/me/parabola/mkgmap/general/MapLine.java	(working copy)
@@ -34,6 +34,7 @@
 
 	private List<Coord> points;
 	private boolean direction; // set if direction is important.
+	private boolean noDirection; // set if style used mkgmap:has-direction=no
 	private boolean skipSizeFilter;
 	private boolean wasClipped;
 	private int minLat = Integer.MAX_VALUE;
@@ -47,6 +48,7 @@
 	public MapLine(MapLine orig) {
 		super(orig);
 		direction = orig.direction;
+		noDirection = orig.noDirection;
 		skipSizeFilter = orig.skipSizeFilter;
 	}
 
@@ -172,5 +174,19 @@
 	public Rectangle getRect(){
 		return new Rectangle(minLong, minLat, maxLong-minLong, maxLat-minLat);
 	}
+
+	/**
+	 * @return the noDirection
+	 */
+	public boolean isNoDirection() {
+		return noDirection;
+	}
+
+	/**
+	 * @param noDirection the noDirection to set
+	 */
+	public void setNoDirection(boolean noDirection) {
+		this.noDirection = noDirection;
+	}
 	
 }
Index: src/uk/me/parabola/mkgmap/osmstyle/StyledConverter.java
===================================================================
--- src/uk/me/parabola/mkgmap/osmstyle/StyledConverter.java	(revision 4725)
+++ src/uk/me/parabola/mkgmap/osmstyle/StyledConverter.java	(working copy)
@@ -218,15 +218,19 @@
 		prefixSuffixFilter = new PrefixSuffixFilter(props);
 
 		lineAdder = line -> {
+			if (!line.isDirection() && !line.isNoDirection() && lineTypesWithDirection.contains(line.getType())) {
+				line.setDirection(true);
+			}
 			if (line instanceof MapRoad) {
-				prefixSuffixFilter.filter((MapRoad) line);
-				if (!line.isDirection() && ((MapRoad) line).getRoadDef().isOneway()) {
-					// we want to set the direction flag for oneway roads because Garmin maps also do it 
-					// do this very late so that overlays are not modified 
-					line.setDirection(true); 
+				MapRoad road = (MapRoad) line;
+				prefixSuffixFilter.filter(road);
+				if (!line.isDirection() && !line.isNoDirection() && road.getRoadDef().isOneway()) {
+					// we want to set the direction flag for oneway roads because Garmin maps also
+					// do it, but we don't want to do that when the tag mkgmap:has-direction was false/0/no  
+					// do this very late so that overlays are not modified
+					road.setDirection(true);
 				}
-								
-				collector.addRoad((MapRoad) line);
+				collector.addRoad(road);
 			} else {
 				collector.addLine(line);
 			}
@@ -1280,6 +1284,8 @@
 		line.setPoints(points);
 
 		line.setDirection(cw.hasDirection()); // used to check oneway as well
+		if (cw.getWay().tagIsLikeNo(TKM_HAS_DIRECTION))
+			line.setNoDirection(true);
 
 		clipper.clipLine(line, lineAdder);
 	}
@@ -1887,6 +1893,8 @@
 			road.setOneway();
 		}
 		road.setDirection(cw.hasDirection()); // ignore oneway here 
+		if (cw.getWay().tagIsLikeNo(TKM_HAS_DIRECTION))
+			road.setNoDirection(true);
 
 		road.setAccess(cw.getAccess());
 		
